@@ -17,16 +17,15 @@ import aws_cdk.aws_lambda._jsii
 import aws_cdk.aws_lambda_event_sources._jsii
 import aws_cdk.aws_sqs._jsii
 import aws_cdk.core._jsii
-import aws_solutions_constructs.aws_dynamodb_stream_lambda._jsii
-import aws_solutions_constructs.aws_lambda_elasticsearch_kibana._jsii
+import aws_solutions_constructs.aws_dynamodbstreams_lambda_elasticsearch_kibana._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-dynamodb-stream-lambda-elasticsearch-kibana",
-    "1.114.0",
+    "1.115.0",
     __name__[0:-6],
-    "aws-dynamodb-stream-lambda-elasticsearch-kibana@1.114.0.jsii.tgz",
+    "aws-dynamodb-stream-lambda-elasticsearch-kibana@1.115.0.jsii.tgz",
 )
 
 __all__ = [
